==> nextcloud-23.0.12p0.tgz: nextcloud/apps/user_status/l10n/de.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Letzter Status",
    "In a meeting" : "In einer Besprechung",
    "Commuting" : "Pendelt",
    "Out sick" : "Krankgeschrieben",
    "Vacationing" : "Im Urlaub",
    "Working remotely" : "Arbeitet aus der Ferne",
    "In a call" : "In einem Anruf",
    "User status" : "Benutzerstatus",
    "View profile" : "Profil ansehen",
    "Clear status after" : "Status löschen nach",
    "What is your status?" : "Wie ist dein Status?",
    "Set status" : "Status setzen",
    "Online status" : "Online-Status",
    "Status message" : "Statusnachricht",
    "Clear status message" : "Statusnachricht löschen",
    "Set status message" : "Statusnachricht setzen",
    "There was an error saving the status" : "Es gab einen Fehler beim Speichern des Status",
    "There was an error clearing the status" : "Es gab einen Fehler beim Löschen des Status",
    "No recent status changes" : "Keine kürzlichen Statusänderungen",
    "Away" : "Abwesend",
    "Do not disturb" : "Bitte nicht stören",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Nicht löschen",
    "Today" : "Heute",
    "This week" : "Diese Woche",
    "Online" : "Online",
    "Invisible" : "Unsichtbar",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Es gab einen Fehler beim Speichern des neuen Status",
    "30 minutes" : "30 Minuten",
    "1 hour" : "1 Stunde",
    "4 hours" : "4 Stunden",
    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
    "Appear offline" : "Offline erscheinen",
    "Clear status message after" : "Statusnachricht löschen nach"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/user_status/l10n/de.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Letzter Status",
    "In a meeting" : "In einer Besprechung",
    "Commuting" : "Pendelt",
    "Out sick" : "Krankgeschrieben",
    "Vacationing" : "Im Urlaub",
    "Working remotely" : "Arbeitet aus der Ferne",
    "In a call" : "In einem Anruf",
    "User status" : "Benutzerstatus",
    "View profile" : "Profil ansehen",
    "Clear status after" : "Status löschen nach",
    "What is your status?" : "Wie ist dein Status?",
    "Previously set" : "Zuvor eingestellt",
    "Reset status" : "Status zurücksetzen",
    "Set status" : "Status setzen",
    "Online status" : "Online-Status",
    "Status message" : "Statusnachricht",
    "Your status was set automatically" : "Dein Status wurde automatisch gesetzt",
    "Clear status message" : "Statusnachricht löschen",
    "Set status message" : "Statusnachricht setzen",
    "Reset status to \"{icon} {message}\"" : "Status auf \"{icon} {message}\" zurücksetzen",
    "Reset status to \"{message}\"" : "Status auf \"{message}\" zurücksetzen",
    "Reset status to \"{icon}\"" : "Status auf \"{icon}\" zurücksetzen",
    "There was an error saving the status" : "Es gab einen Fehler beim Speichern des Status",
    "There was an error clearing the status" : "Es gab einen Fehler beim Löschen des Status",
    "There was an error reverting the status" : "Es ist ein Fehler beim Zurücksetzen des Status aufgetreten",
    "No recent status changes" : "Keine kürzlichen Statusänderungen",
    "Away" : "Abwesend",
    "Do not disturb" : "Bitte nicht stören",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Nicht löschen",
    "Today" : "Heute",
    "This week" : "Diese Woche",
    "Online" : "Online",
    "Invisible" : "Unsichtbar",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Es gab einen Fehler beim Speichern des neuen Status",
    "30 minutes" : "30 Minuten",
    "1 hour" : "1 Stunde",
    "4 hours" : "4 Stunden",
    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
    "Appear offline" : "Offline erscheinen",
    "Clear status message after" : "Statusnachricht löschen nach"
},
"nplurals=2; plural=(n != 1);");
